{% load admin_tools_menu_tags %}
{% spaceless %}
{% if not item.is_empty %}
<li class="menu-item{% ifequal index 1 %} first{% endifequal %}{% if not item.enabled %} disabled{% endif %}{% if selected %} selected{% endif %}{% if item.css_classes %} {{ item.css_classes|join:' ' }}{% endif %}">
    <a href="{% if item.url and item.enabled %}{{ item.url }}{% else %}#{% endif %}"{% if item.description %} title="{{ item.description }}"{% endif %}{% if item.accesskey %} accesskey="{{ item.accesskey }}"{% endif %}{% if item.children and item.enabled %} class="has-icon"{% endif %}>{{ item.title|capfirst }}</a>
    {% if item.children and item.enabled %}
    <ul>
        {% for child_item in item.children %}
        {% admin_tools_render_menu_item child_item %}
        {% endfor %}
    </ul>
    {% endif %}
</li>
{% endif %}
{% endspaceless %}
