/* Utilities {{{ */

.float-right {
    float: right;
}

/* }}} */
/* Dashboard general styles {{{ */

.warning {
    color: red;
    background: transparent url(../images/admin-tools.png) 0 -412px no-repeat;
    padding-left: 25px;
}

.dashboard #content {
    display: block;
    width: auto; !important;
    margin: 15px 5px;
}

.dashboard-container {
    clear: both;
}

h1.dashboard-title {
    float: left;
    padding-bottom: 0;
    margin: 0 10px;
}

#dashboard-panel {
    margin: 0 10px 0 0;
    float: right;
}

#dashboard-panel h3 a {
    padding: 5px;
    min-width: 100px;
    display: block;
    text-align: center;
    border: 1px solid #e5e5e5;
    -moz-border-radius: 6px;
    -webkit-border-radius: 6px;
}

#dashboard-panel ul {
    display: none;
    position: absolute;
    top: auto;
    right: 25px;
    margin-top: -1px;
}

#dashboard-panel ul li {
    padding: 5px;
    border: 1px solid #e5e5e5;
    background-color: white;
}

#dashboard-panel ul li a {
    display: block;
}

#dashboard-panel:hover ul {
    display: block;
}

.dashboard ul {
    margin: 0;
    padding: 0;
    list-style: none;
}

.dashboard ul li {
    list-style: none;
}

.dashboard-column {
    width: 49.9%;  
    float: left;
    min-height: 200px;
}

.dashboard-module {
    margin: 10px 10px 5px 10px;
    padding: 0;
    border: 1px solid #e5e5e5;
    -moz-border-radius: 6px;
    -webkit-border-radius: 6px;
}

.dashboard-placeholder {
    border: 2px dashed #cbe0ff;
	background-color: #f8f8f8;
    margin: 10px 10px 5px 10px;
}

.dashboard-module h2 {
    margin: 0;
    padding: 7px 5px 8px 8px;
    text-align: left;
    font-weight: normal;
	background: #f8f8f8;
    height: 20px;
    color: #555;
}

.dashboard-module.draggable h2 {
    cursor: move;
}

.dashboard-module h2 a.toggle-icon,
.dashboard-module h2 a.close-icon {
    text-indent: -9999px;
    display: block;
    float: right;
    height: 20px;
    width: 17px;
    margin: 0 0 0 5px;
    cursor: pointer;
    background-image: url(../images/admin-tools.png);
    background-repeat: no-repeat;
}

.dashboard-module h2 a.toggle-icon {
    background-position: 0 -45px;
}

.dashboard-module h2 a.toggle-icon:hover {
    background-position: 0 -65px;
}

.dashboard-module h2 a.toggle-icon.collapsed {
    background-position: 0 -85px;
}

.dashboard-module h2 a.toggle-icon.collapsed:hover {
    background-position: 0 -105px;
}

.dashboard-module h2 a.close-icon {
    background-position: 0 -125px;
}

.dashboard-module h2 a.close-icon:hover {
    background-position: 0 -145px;
}

.fixed h2 span.toggle-icon,
.fixed h2 span.close-icon {
    display: none;
}

.dashboard-module h3 {
    padding: 5px 8px;
    margin: 0;
    background: #fafafa;
    height: 22px;
}

.dashboard-module h3 a {
    margin: 0;
    color: #666;
    font-size: 13px;
    font-weight: normal;
}

.dashboard-module-content {
    border-top: 1px solid #ececec;
}

.dashboard-module-content a {
    color: #5B80B2;
}

.dashboard-module-content p {
    margin: 10px;
}

.dashboard-module ul li {
    vertical-align: top;
    padding: 5px 8px;
    line-height: 20px;
}

.dashboard-module ul li.odd {
    background: #f5f5f5;
}

.dashboard-module ul li.even {
    background: #ffffff;
}

.dashboard-module ul li a.external-link {
    background-image: url(../images/admin-tools.png);
    background-repeat: no-repeat;
    background-position: -5px -168px;
    padding-left: 15px;
}

.dashboard-module ul li ul {
    float: right;
}

.dashboard-module ul li ul li {
    display: block;
    float: left;
    border: 0;
    padding: 0 5px;
    vertical-align: top;
    height: auto;
    line-height: auto;
}

.dashboard-module ul li:hover {
    background: #fffff4;
}

/* }}} */
/* link list specific styles {{{ */


.dashboard-module ul.inline {
    display: block;
    height: auto;
    padding: 15px;
    text-align: center;
}

.dashboard-module ul.inline li {
    display: inline;
    margin: 10px auto;
}

.dashboard-module ul.inline li.odd,
.dashboard-module ul.inline li.even {
    background: none;
}

/* }}} */
/* Dashboard groups {{{ */

.group {
    border: 0;
    margin: 0;
    padding: 0;
}

.group ul {
    background: none;
    background-color: #fafafa;
    border-width: 0 0 1px 0;
    border-color: #d3d3d3;
    -moz-border-radius: 0;
    -webkit-border-radius: 0;
    border-radius: 0;
}

.group ul li.group-tabs-link {
    margin-top: 7px;
}

.group ul li.group-tabs-link a:focus,
.group ul li.group-tabs-link a:active {
    border: none;
    outline: none;
}

.group .dashboard-module {
    padding: 5px;
    margin: 0;
}

.group-accordion .group-accordion-header {
    display: block;
    clear: both;
    border: none;
    -moz-border-radius: 0;
    -webkit-border-radius: 0;
    border-radius: 0;
    border-bottom: 1px solid #d3d3d3;
    margin: 0;
    background: none;
    background-color: #f6f6f6;
}

.group-accordion .group-accordion-header.ui-state-default {
    background-color: #f0f0f0;
}

.group-accordion .dashboard-module {
    border: 0;
}


/* }}} */
