{% extends "admin/base_site.html" %}

{% block content %}

<p>Are you sure you want to delete this bookmark?</p>

<p>{{ bookmark.name }} - {{ bookmark.url }}</p>

<form action="." method="POST">
    <p><input type="submit" value="Delete" /></p>
</form>

{% endblock %}
