from .autocomplete_fields import AdminAutocompleteFieldsMixin
from .generic_foreign_key import GenericForeignKeyAdminMixin
from .generic_foreign_key_inline import GenericForeignKeyInlineAdminMixin
from .admin_clickable_links import AdminClickableLinksMixin
